from sys import exit
def engToUwU(text: str) -> str:
    return text.lower().replace('l',  'w').replace('r', 'w').replace('k', 'w')
print('--- UwU Lang ---')
while True:
    try:
        print(engToUwU(input('>> ')))
    except KeyboardInterrupt:
        print('Bye!')
        exit()



from setuptools import setup, find_packages

setup(
name='uwulang',
version='1.0.0',
description='UwU',
long_description='''UwU Lang.
Sample:
Hello, world!
hewwo, wowwd!
l - w
k - w
r - w
Enjoy it!''',
long_description_content_type='text/plain',
install_requires=[],
packages=find_packages(),
author='kanderusss'
)
